# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()" 2>/dev/null)}
%global pythonver %(%{__python} -c "import sys; print sys.version[:3]" 2>/dev/null || echo 0.0)

Summary:	Python serial port access library
Name:		pyserial
Version:	2.7
Release:	1.%{__distinit}%{__distvers}
License:	Python
Group:		Development/Libraries
URL:		http://pyserial.sourceforge.net/
Source0:	http://pypi.python.org/packages/source/p/pyserial/pyserial-%{version}.tar.gz
Patch0:		pyserial-2.5-py23.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	python2-devel
BuildArch:	noarch

%description
This module encapsulates the access for the serial port. It provides back-ends
for standard Python running on Windows, Linux, BSD (possibly any POSIX
compliant system) and Jython. The module named "serial" automatically selects
the appropriate back-end.

%prep
export UNZIP="-aa"
%setup -q

# Fix python 2.3 compatibility
%if "%{pythonver}" == "2.3"
%patch0 -p1
%endif

# Strip out shellbangs, except for miniterm.py where it's needed
mv serial/tools/miniterm.py .
sed -i -e '/^#!.*ython[[:space:]]*$/d' serial/{,tools/,urlhandler/}*.py
mv miniterm.py serial/tools/

# Fix line endings
sed -i -e 's/\r$//' examples/port_publisher.py

%build
%{__python} setup.py build

%install
rm -rf %{buildroot}
%{__python} setup.py install -O1 --skip-build --root %{buildroot}

# Make sure that we have something to exclude in %%{_bindir}
touch %{buildroot}%{_bindir}/dummy.pyc
touch %{buildroot}%{_bindir}/dummy.pyo

# Make miniterm.py executable to silence rpmlint
chmod -c +x %{buildroot}%{python_sitelib}/serial/tools/miniterm.py

# See if there's any egg-info
if [ -f %{buildroot}%{python_sitelib}/pyserial-%{version}-py%{pythonver}.egg-info ]; then
	echo %{python_sitelib}/pyserial-%{version}-py%{pythonver}.egg-info
fi > egg-info

%check
# Tests require a hardware dongle
#cd test
#python run_all_tests.py
#cd -

%clean
rm -rf %{buildroot}

%files -f egg-info
%defattr(-,root,root,-)
%doc LICENSE.txt CHANGES.txt README.txt documentation/ examples/
%{_bindir}/miniterm.py
%{python_sitelib}/serial/
%exclude %{_bindir}/*.pyc
%exclude %{_bindir}/*.pyo

%changelog
* Fri Oct 18 2013 Paul Howarth <paul@city-fan.org> - 2.7-1
- Update to 2.7 (see CHANGES.txt for details)

* Mon Nov 28 2011 Paul Howarth <paul@city-fan.org> - 2.6-1
- Update to 2.6:
  - moved some of the examples to serial.tools so that they can be used with
    'python -m'
  - serial port enumeration now included as 'serial.tools.list_ports'
  - URL handers for 'serial_for_url' are now imported dynamically; this allows
    to add protocols wthout editing files
  - new URL type: hwgrep://<regexp> uses list_ports module to search for ports
    by their description
  - several internal changes to improve Python 3.x compatibility (setup.py,
    use of absolute imports and more)
  - calling open() on an already open port now raises an exception
    (Bug 3093882)
  - rfc2217 server hangs in closed loop after connection lost (Bug 3245627)
  - readlines() to support multi-character eol (Patch 3147043)
  - avoid unneeded termios.tcsetattr calls in serialposix.py (Patch 3316943)
  - serial scan as a module with Mac support (Patch 2912349)
  - writeTimeoutError when write Timeout is 0 (Bug 3057499)
  - character out of range in list_ports_windows (Bug 3414327)
  - Windows 98 support fix (Patch 3036175)
  - RTS automatic toggle, for RS485 functionality (Patch 3054352)
  - fix type definitions for 64 bit Windows compatibility
- Upstream source is now on pypi.python.org
- Remove more spurious shellbangs

* Thu Aug  4 2011 Paul Howarth <paul@city-fan.org> - 2.5-2
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux
- Simplify shellbang stripping in %%prep

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> - 2.5-1
- Import from Fedora
- Update to 2.5:
  - Python 3.x support (through 2to3)
  - compatible with Python io library (Python 2.6+)
  - 1.5 stop bits (STOPBITS_ONE_POINT_FIVE) implemented
  - miniterm application extended (CTRL+T -> menu)
  - miniterm.py is now installed as "script"
  - add `getSettingsDict' and `applySettingsDict' serial object methods`
  - add a `poll'-based implementation on Posix
  - add `loop://' device for testing`
  - add `serial.serial_for_url' factory function
  - new examples: `port_publisher', `scanlinux.py', `rfc2217_server.py'
  - experimental RFC-2217 server support (examples/rfc2217_server.py)
  - experimental RFC-2217 client support (serial.rfc2217.Serial, see docs)
  - tests moved to their own directory
  - fix 5-bit mode (needs 1.5 stop bits in some cases) (Bug 2603052)
  - propagate exceptions raised in serialposix _reconfigure (Bug 2810169)
  - improve and fix tcp_serial_redirector example
  - fix suboption parsing in rfc2217 (Bug 2915810)
  - improve write timeout behaviour
  - improve `xreadlines'
  - move Linux-specific constants to not break other platforms (Bug 2836297)
  - fix error handling in `read' to detect disconnected devices
  - `dsrdtr' parameter defaults to `False' (Bug 2976262)
  - fix exception in test.py with python 3.1 (Bug 2925854)
  - fix nonblocking error - Unix platform (Bug 3006606)
- Remove shellbangs and fix line endings to placate rpmlint
- Add %%check section, but don't enable it as it requires a hardware dongle

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Sun Oct 18 2009 Paul P Komkoff Jr <i@stingr.net> - 2.4-1
- New upstream version

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 2.2-7
- Rebuild for Python 2.6

* Fri Aug 29 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2-6
- Fix license tag

* Tue Dec 12 2006 Paul P. Komkoff Jr <i@stingr.net>
- Rebuilt

* Mon Nov  6 2006 Paul P Komkoff Jr <i@stingr.net> - 2.2-4
- Remove "export libdirname"

* Tue Oct 24 2006 Paul P Komkoff Jr <i@stingr.net> - 2.2-3
- Minor specfile fixes

* Sat Oct 14 2006 Paul P Komkoff Jr <i@stingr.net> - 2.2-2
- Minor specfile fixes

* Tue May  9 2006 Paul P Komkoff Jr <i@stingr.net> - 2.2-1
- Fedora Extras submission
